package javax.accessibility;

import java.util.Enumeration;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import java.util.Locale;
import java.util.Hashtable;

public abstract class AccessibleBundle
{
    private static Hashtable table;
    private final String defaultResourceBundleName = "com.sun.accessibility.internal.resources.accessibility";
    protected String key;
    
    public AccessibleBundle() {
        this.key = null;
    }
    
    protected String toDisplayString(String s, Locale key) {
        this.loadResourceBundle(s, key);
        Object value = AccessibleBundle.table.get(key);
        if (value != null && value instanceof Hashtable) {
            Object value2 = ((Hashtable)value).get(this.key);
            if (value2 != null && value2 instanceof String) {
                return (String)value2;
            }
        }
        return this.key;
    }
    
    public String toDisplayString(Locale locale) {
        return this.toDisplayString("com.sun.accessibility.internal.resources.accessibility", locale);
    }
    
    public String toDisplayString() {
        return this.toDisplayString(Locale.getDefault());
    }
    
    @Override
    public String toString() {
        return this.toDisplayString();
    }
    
    private void loadResourceBundle(String baseName, Locale key) {
        if (!AccessibleBundle.table.contains(key)) {
            try {
                Hashtable<String, Object> value = new Hashtable();
                ResourceBundle bundle = ResourceBundle.getBundle(baseName, key);
                Enumeration<String> keys = bundle.getKeys();
                while (keys.hasMoreElements()) {
                    String s = (String)keys.nextElement();
                    value.put(s, bundle.getObject(s));
                }
                AccessibleBundle.table.put(key, value);
            }
            catch (MissingResourceException obj) {
                System.err.println("loadResourceBundle: " + obj);
                return;
            }
        }
    }
    
    static {
        AccessibleBundle.table = new Hashtable();
    }
}
